@@ -647,9 +647,10 @@ spi_atk_emit_eventv (const GObject         *gobject,
 #endif
       CORBA_exception_init (&ev);
       registry = spi_atk_bridge_get_registry ();
-      if (registry_died)
+      if (registry_died) {
+        g_free (e.type);
         return;
-        
+      }  
       Accessibility_Registry_notifyEvent (registry, 
 					  &e, &ev);
 #ifdef SPI_BRIDGE_DEBUG
@@ -1041,6 +1042,8 @@ spi_atk_bridge_signal_listener (GSignalInvocationHint *signal_hint,
 
   if (sp)
     g_free (sp);
+  if (any._release)
+    CORBA_free (any._value);
 
   return TRUE;
 }
